/* Code to replicate The Economic Consequences of Forced Displacement. Journal of Development Studies, 2015, 51 (10): 1275-1293. */

set matsize 500                                       
clear
set more off
ssc install outreg2
*use idp.dta
use "displacement.dta" 



// Create global macros
gen diffassets=aindex2008-aindex1999

global ctrls "educ female single singlefemale agriculture size logage educ2 size2 logage2 death"
global ctrls2008 "educ female single singlefemale agriculture size logage educ2 size2 logage2 death aindex2004"
global balance "single agriculture age size death aindex1999"
global outcomes2004 "aindex2004"
global outcomes2008 "logc2008per aindex2008 diffassets avgeduc2008 protein2008 remittances2008 occ_ag"


// Create selection weights
svyset [pweight=mult], psu(COMM)
svy: logit idp2004 $ctrls
predict pscore2004

svyset [pweight=pscore2004], psu(COMM)
svy: logit found idp2004 $ctrls2008
predict pscore2008


// Table 1: Summary stats
sum logc2004per aindex2004 educ female single agriculture age size death idp2004 consumption_g aindex2008 educ2008 logc2008per avgeduc2008 protein2008 remittances2008 occ_ag aindex1999 [iw=pscore2004]
sum logc2004per aindex2004 educ female single agriculture age size death idp2004 consumption_g aindex2008 educ2008 logc2008per avgeduc2008 protein2008 remittances2008 occ_ag aindex1999 [iw=pscore2004] if smallsamp==1


// Table 2: Balance tests 
svyset [pweight=pscore2004], psu(COMM)
svy: reg female idp2004
	outreg2 idp2004 using balance,  bracket coefastr se
foreach x in $balance {
	svy: reg `x' idp2004 
		outreg2 idp2004 using balance,  bracket coefastr se append
	}	

svyset [pweight=pscore2004], psu(COMM)
svy: reg female idp2004 if smallsamp==1
	outreg2 idp2004 using balance,  bracket coefastr se append
foreach x in $balance {
	svy: reg `x' idp2004  if smallsamp==1
		outreg2 idp2004 using balance,  bracket coefastr se append
	}	


// Table 3: 2004 outcomes
svyset [pweight=pscore2004], psu(COMM)
svy: reg logc2004per idp2004 
	outreg2 idp2004 using outcomes2004,  bracket coefastr se
foreach x in $outcomes2004 {
	svy: reg `x' idp2004 
		outreg2 idp2004 using outcomes2004,  bracket coefastr se append
	}	

svyset [pweight=pscore2004], psu(COMM)
svy: reg logc2004per idp2004 $ctrls 
	outreg2 idp2004 using outcomes2004,  bracket coefastr se append
foreach x in $outcomes2004 {
	svy: reg `x' idp2004 $ctrls 
		outreg2 idp2004 using outcomes2004,  bracket coefastr se append
	}	

reg logc2004per idp2004 $ctrls 
	outreg2 idp2004 using outcomes2004,  bracket coefastr se append
foreach x in $outcomes2004 {
	reg `x' idp2004 $ctrls 
		outreg2 idp2004 using outcomes2004,  bracket coefastr se append
	}	

svyset [pweight=pscore2004], psu(COMM)
svy: reg logc2004per idp2004  if smallsamp==1
	outreg2 idp2004 using outcomes2004,  bracket coefastr se append
foreach x in $outcomes2004 {
	svy: reg `x' idp2004  if smallsamp==1
		outreg2 idp2004 using outcomes2004,  bracket coefastr se append
	}	

svyset [pweight=pscore2004], psu(COMM)
svy: reg logc2004per idp2004 $ctrls  if smallsamp==1
	outreg2 idp2004 using outcomes2004,  bracket coefastr se append
foreach x in $outcomes2004 {
	svy: reg `x' idp2004 $ctrls  if smallsamp==1
		outreg2 idp2004 using outcomes2004,  bracket coefastr se append
	}	

reg logc2004per idp2004 $ctrls  if smallsamp==1
	outreg2 idp2004 using outcomes2004,  bracket coefastr se append
foreach x in $outcomes2004 {
	reg `x' idp2004 $ctrls  if smallsamp==1
		outreg2 idp2004 using outcomes2004,  bracket coefastr se append
	}	


// Table 3: Outcomes 2008
svyset [pweight=pscore2008], psu(COMM)
svy: reg consumption_g idp2004 
	outreg2 idp2004 using outcomes2008,  bracket coefastr se
foreach x in $outcomes2008 {
	svy: reg `x' idp2004 
		outreg2 idp2004 using outcomes2008,  bracket coefastr se append
	}	

svyset [pweight=pscore2008], psu(COMM)
svy: reg consumption_g idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	svy: reg `x' idp2004 $ctrls2008 
		outreg2 idp2004 using outcomes2008,  bracket coefastr se append
	}	

reg consumption_g idp2004 $ctrls2008 
	outreg2 idp2004 using outcomes2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	reg `x' idp2004 $ctrls2008 
		outreg2 idp2004 using outcomes2008,  bracket coefastr se append
	}	

svyset [pweight=pscore2008], psu(COMM)
svy: reg consumption_g idp2004  if smallsamp==1
	outreg2 idp2004 using outcomes2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	svy: reg `x' idp2004  if smallsamp==1
		outreg2 idp2004 using outcomes2008,  bracket coefastr se append
	}	

svyset [pweight=pscore2008], psu(COMM)
svy: reg consumption_g idp2004 $ctrls2008  if smallsamp==1
	outreg2 idp2004 using outcomes2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	svy: reg `x' idp2004 $ctrls2008  if smallsamp==1
		outreg2 idp2004 using outcomes2008,  bracket coefastr se append
	}	

reg consumption_g idp2004 $ctrls2008  if smallsamp==1
	outreg2 idp2004 using outcomes2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	reg `x' idp2004 $ctrls2008  if smallsamp==1
		outreg2 idp2004 using outcomes2008,  bracket coefastr se append
	}	

	
// Table 4: Heterogeneity by 1999 assets, top quartile
sum aindex1999, d

gen top75=0
replace top75=1 if aindex1999>-1.071574
replace top75=. if aindex1999==.

gen idp_top75=idp2004*top75

gen top50=0
replace top50=1 if aindex1999>-.1296155
replace top50=. if aindex1999==.

gen idp_top50=idp2004*top50

gen top25=0
replace top25=1 if aindex1999>.6137912
replace top25=. if aindex1999==.

gen idp_top25=idp2004*top25


svyset [pweight=pscore2008], psu(COMM)
svy: reg consumption_g idp2004 idp_top75 top75 
	outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se
foreach x in $outcomes2008 {
	svy: reg `x' idp2004 idp_top75 top75 
		outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
	}	

svyset [pweight=pscore2008], psu(COMM)
svy: reg consumption_g idp2004 idp_top75 top75 $ctrls2008 
	outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	svy: reg `x' idp2004 idp_top75 top75 $ctrls2008
		outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
	}	

reg consumption_g idp2004 idp_top75 top75 $ctrls2008
	outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	reg `x' idp2004 idp_top75 top75 $ctrls2008
		outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
	}	

svyset [pweight=pscore2008], psu(COMM)
svy: reg consumption_g idp2004 idp_top75 top75  if smallsamp==1
	outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	svy: reg `x' idp2004 idp_top75 top75  if smallsamp==1
		outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
	}	

svyset [pweight=pscore2008], psu(COMM)
svy: reg consumption_g idp2004 idp_top75 top75 $ctrls2008  if smallsamp==1
	outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	svy: reg `x' idp2004 idp_top75 top75 $ctrls2008  if smallsamp==1
		outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
	}	

reg consumption_g idp2004 idp_top75 top75 $ctrls2008  if smallsamp==1
	outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
foreach x in $outcomes2008 {
	reg `x' idp2004 idp_top75 top75 $ctrls2008  if smallsamp==1
		outreg2 idp2004 idp_top75 top75 using top2008,  bracket coefastr se append
	}	
	
	
// Table A1: Attrition
svyset [pweight=pscore2004], psu(COMM)
svy: logit found idp2004 $ctrls2008
outreg2 idp2004 $ctrls2008 using attrition, se  bracket coefastr 

	
// Table A3: Bounding outcomes 2008 10% SD
foreach x in $outcomes2008 {
	sum `x' if idp2004==1, d
	replace `x'=r(mean)+0.1*r(sd) if idp2004==1 & found==0
	}	

foreach x in $outcomes2008 {
	sum `x' if idp2004==0, d
	replace `x'=r(mean)-0.1*r(sd) if idp2004==0 & found==0
	}	


svyset [pweight=pscore2008], psu(COMM)

svy: reg logc2008per idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append

svy: reg aindex2008 idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append


foreach x in $outcomes2008 {
	sum `x' if idp2004==1, d
	replace `x'=r(mean)-0.1*r(sd) if idp2004==1 & found==0
	}	

foreach x in $outcomes2008 {
	sum `x' if idp2004==0, d
	replace `x'=r(mean)+0.1*r(sd) if idp2004==0 & found==0
	}	


svyset [pweight=pscore2008], psu(COMM)

svy: reg logc2008per idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append

svy: reg aindex2008 idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append


// Table A3: Bounding outcomes 2008 25% SD
foreach x in $outcomes2008 {
	sum `x' if idp2004==1, d
	replace `x'=r(mean)+0.25*r(sd) if idp2004==1 & found==0
	}	

foreach x in $outcomes2008 {
	sum `x' if idp2004==0, d
	replace `x'=r(mean)-0.25*r(sd) if idp2004==0 & found==0
	}	

svyset [pweight=pscore2008], psu(COMM)

svy: reg logc2008per idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append

svy: reg aindex2008 idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append


	foreach x in $outcomes2008 {
	sum `x' if idp2004==1, d
	replace `x'=r(mean)-0.25*r(sd) if idp2004==1 & found==0
	}	

foreach x in $outcomes2008 {
	sum `x' if idp2004==0, d
	replace `x'=r(mean)+0.25*r(sd) if idp2004==0 & found==0
	}	

svyset [pweight=pscore2008], psu(COMM)

svy: reg logc2008per idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append

svy: reg aindex2008 idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append

	

// Table A3: Bounding outcomes 2008 50% SD
foreach x in $outcomes2008 {
	sum `x' if idp2004==1, d
	replace `x'=r(mean)+0.5*r(sd) if idp2004==1 & found==0
	}	

foreach x in $outcomes2008 {
	sum `x' if idp2004==0, d
	replace `x'=r(mean)-0.5*r(sd) if idp2004==0 & found==0
	}	


svyset [pweight=pscore2008], psu(COMM)

svy: reg logc2008per idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append

svy: reg aindex2008 idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append


foreach x in $outcomes2008 {
	sum `x' if idp2004==1, d
	replace `x'=r(mean)-0.5*r(sd) if idp2004==1 & found==0
	}	

foreach x in $outcomes2008 {
	sum `x' if idp2004==0, d
	replace `x'=r(mean)+0.5*r(sd) if idp2004==0 & found==0
	}	


svyset [pweight=pscore2008], psu(COMM)

svy: reg logc2008per idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append

svy: reg aindex2008 idp2004 $ctrls2008
	outreg2 idp2004 using outcomes2008b,  bracket coefastr se append
	
	
	
// Table A4: Effect of violent shock
svyset [pweight=pscore2004], psu(COMM)

gen acledfight=0
replace acledfight=1 if subounty == "OKWANG" | subounty == "APALA" | subounty == "OMORO" | subounty == "AMUGO" | subounty == "ADEKOKWOK" | subounty == "DOKOLO"

svy: reg consumption_g acledfight $ctrls2008 if idp2004==1
	outreg2 acledfight using conflict,  bracket coefastr se append

foreach x in $outcomes2008 {
	svy: reg `x' acledfight $ctrls2008 if idp2004==1
		outreg2 acledfight using conflict,  bracket coefastr se append
	}	


foreach x in $outcomes2008 {
	svy: reg `x' acledfight $ctrls2008 if idp2004==0
		outreg2 acledfight using conflict,  bracket coefastr se append
	}	
	
	
// Graphs
hist aindex2008 , bin(15) norm xlabel(-2(2)8)
hist aindex2008 if idp2004==1, bin(15) norm xlabel(-2(2)8)
hist aindex2008 if idp2004==0, bin(15) norm xlabel(-2(2)8)


	
exit


// Table A2: Placebo test
********************* Part 8 Placebo test ************************
set matsize 500                                       
clear
set more off

*use placebo.dta
use "\\tsclient\mac\Desktop\replication\Displacement\placebo.dta" 

tab  DISTRICT, gen (districts)

global district "districts1 districts2 districts3 districts4 districts5 districts6 districts7 districts8 districts9 districts10 districts11 districts12 districts13 districts14 districts15 districts16 districts17 districts18"

drop if idp2004==1

replace smallsamp=0 if smallsamp==. & districts12==1

svyset [pweight=HMULT], psu(COMM)

svy: reg logcon smallsamp 
	outreg2 smallsamp using placebo, bracket coefastr se append

svy: reg aindex smallsamp
	outreg2 smallsamp using placebo, bracket coefastr se append
	
foreach y in $district {

svy: reg logcon districts12 if districts12==1 | `y'==1
	outreg2 districts12 using placebo, bracket coefastr se append
}

foreach y in $district {

svy: reg aindex districts12 if districts12==1 | `y'==1
	outreg2 districts12 using placebo, bracket coefastr se append
}

exit


